@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Mouse;
 
-our $VERSION = '0.0.9';
+our $VERSION = '0.0.10';
 
 #_* Libraries
 
@@ -19,7 +19,7 @@ Proc::Launcher - yet another forking process controller
 
 =head1 VERSION
 
-version 0.0.9
+version 0.0.10
 
 =head1 SYNOPSIS
 
@@ -275,6 +275,10 @@ sub start {
         # child
         if ( $self->class ) {
             my $method = $self->start_method;
+
+            my $class = $self->class;
+            eval "use $class"; ## no critic
+
             $self->class->new( context => $self->context )->$method( $args );
         }
         else {
@@ -353,7 +357,7 @@ sub is_running {
 
     if ( kill 0, $self->pid ) {
         print "STILL RUNNING\n" if $self->debug;
-        return 1;
+        return $self->daemon_name;
     }
 
     print "PROCESS NOT RUNNING\n" if $self->debug;
@@ -538,6 +542,7 @@ sub read_log {
     return 1;
 }
 
+no Mouse;
 
 1;
 
